@@ -8,8 +8,9 @@ from collections import OrderedDict, defaultdict
 from itertools import groupby
 
 from sql import Literal, Union, Column, Null, For
-from sql.aggregate import Sum
+from sql.aggregate import Max, Sum
 from sql.conditionals import Coalesce, Case
+from sql.functions import Round
 
 from trytond.i18n import gettext
 from trytond.model import Workflow, Model, ModelView, ModelSQL, fields, Check
@@ -119,6 +120,8 @@ class StockMixin(object):
         pool = Pool()
         Product = pool.get('product.product')
         Move = pool.get('stock.move')
+        Uom = pool.get('product.uom')
+        uom = Uom.__table__()
 
         if not location_ids or not domain:
             return []
@@ -136,7 +139,12 @@ class StockMixin(object):
                 query = Move.compute_quantities_query(
                     location_ids, with_childs, grouping=grouping)
                 col_id = Column(query, grouping[position])
-                quantity = Sum(query.quantity)
+                # We need to round the result to have same result as
+                # products_by_location but as we do not have the unit, we use
+                # the biggest digits of all unit as best approximation.
+                quantity = Round(
+                    fields.Numeric('quantity').sql_cast(Sum(query.quantity)),
+                    uom.select(Max(uom.digits)))
                 group_by = [Column(query, key).as_(key) for key in grouping]
                 return [('id', 'in', query.select(
                             col_id,
@@ -158,7 +166,8 @@ class StockMixin(object):
             }.get(operator_, lambda v, l: False)
         record_ids = []
         for key, quantity in pbl.items():
-            if operator_(quantity, operand):
+            if (quantity is not None and operand is not None
+                    and operator_(quantity, operand)):
                 # pbl could return None in some keys
                 if key[position] is not None:
                     record_ids.append(key[position])
@@ -298,6 +307,7 @@ class Move(Workflow, ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Move, cls).__setup__()
+        cls.create_date.select = True
         cls.product.domain = [
             If(Bool(Eval('product_uom_category'))
                 & ~Eval('state').in_(['done', 'cancelled']),
@@ -366,9 +376,6 @@ class Move(Workflow, ModelSQL, ModelView):
         super(Move, cls).__register__(module_name)
         table = cls.__table_handler__(module_name)
 
-        # Add index on create_date
-        table.index_action('create_date', action='add')
-
         # Index for period join in compute_quantities_query
         table.index_action([
                 Coalesce(sql_table.effective_date,
